module PolyglotCli
  module Command
    class Pull
      include Helper::Nest
      include Helper::Terminal
      include Helper::General

      def self.init(options)
        new(options).call
      end

      def initialize(options)
        @options = options
      end

      def call
        languages(option_locale).each do |language|
          PolyglotCli::IO::Locale.write(locale_path, translation_hash(language))
        end
        update_config
        success
      end

      private

      def locale_path
        option_path || config[:locale_path]
      end

      def option_locale
        @options.locale
      end

      def option_path
        @options.path
      end

      def translation_hash(language)
        hash = { language.locale => {} }

        remote_translations(language).each do |t|
          hash[language.locale].deep_merge!(nest(t.translation_key.name, t.value))
        end

        hash
      end
    end
  end
end
