module PolyglotCli
  module Helper
    module General
      def token
        @token ||= PolyglotCli::IO::Token.read
      end

      def subdomain
        config[:subdomain]
      end

      def config
        @config ||= PolyglotCli::IO::Config.read
      end

      def project_id
        config[:project_id]
      end

      def project
        prompt.say('Getting project...')
        PolyglotCli::Resource::Project.with_subdomain(subdomain).token(token).find(project_id).first
      end

      def server_changed?
        return true if config[:project_updated_at].nil?
        Time.parse(project.updated_at).utc > Time.parse(config[:project_updated_at]).utc
      end

      def languages(locale = nil)
        prompt.say('Getting languages...')
        select_languages(
          locale,
          PolyglotCli::Resource::Language.with_subdomain(subdomain).token(token).depaginate(project_id: project_id)
        )
      end

      def select_languages(locale, results)
        results.select! { |l| l.locale == locale } if locale.present?

        if config[:locale_mapping].present?
          results.select! do |l|
            l.locale = config[:locale_mapping][l.locale]
            l.locale.present?
          end
        end

        results
      end

      def update_config
        config[:project_updated_at] = project.updated_at
        PolyglotCli::IO::Config.write(config)
      end

      def remote_translations(language)
        prompt.say("Getting #{language.name} translations...")
        PolyglotCli::Resource::Translation.with_subdomain(subdomain).token(token).depaginate(project_id: project_id, language_id: language.id)
      end
    end
  end
end
